@@ -18,7 +18,7 @@ CREATE TABLE autoreg_host (
         host            varchar(64)             DEFAULT ''      NOT NULL,
         PRIMARY KEY (autoreg_hostid)
 ) with OIDS;
-CREATE UNIQUE INDEX autoreg_host_1 on autoreg_host (proxy_hostid,host);
+CREATE INDEX autoreg_host_1 on autoreg_host (proxy_hostid,host);
 alter table config add dropdown_first_entry            integer         DEFAULT '1'     NOT NULL;
 alter table config add dropdown_first_remember         integer         DEFAULT '1'     NOT NULL;
 alter table config add discovery_groupid               bigint          DEFAULT '0'     NOT NULL;
@@ -127,34 +127,48 @@ CREATE TABLE help_items (
         PRIMARY KEY (itemtype,key_)
 ) with OIDS;
 
-insert into help_items values (3,'icmpping[&lt;ip&gt;,&lt;count&gt;,&lt;interval&gt;,&lt;size&gt;,&lt;timeout&gt;]','Checks if server is accessible by ICMP ping0 - ICMP ping fails 1 - ICMP ping successfulOne of zabbix_server processes performs ICMP pings once per PingerFrequency seconds.');
-insert into help_items values (3,'icmppingloss[&lt;ip&gt;,&lt;count&gt;,&lt;interval&gt;,&lt;size&gt;,&lt;timeout&gt;]','Returns percentage of lost ICMP ping packets');
-insert into help_items values (3,'icmppingsec[&lt;ip&gt;,&lt;count&gt;,&lt;interval&gt;,&lt;size&gt;,&lt;timeout&gt;,&lt;type&gt;]','Returns ICMP ping response timeNumber of seconds Example: 0.02');
-insert into help_items values (3,'ftp&lt;,port&gt;','Checks if FTP server is running and accepting connections0 - FTP server is down 1 - FTP server is running');
-insert into help_items values (3,'http&lt;,port&gt;','Checks if HTTP (WEB) server is running and accepting connections0 - HTTP server is down 1 - HTTP server is running');
-insert into help_items values (3,'imap&lt;,port&gt;','Checks if IMAP server is running and accepting connections0 - IMAP server is down 1 - IMAP server is running');
-insert into help_items values (3,'nntp&lt;,port&gt;','Checks if NNTP server is running and accepting connections0 - NNTP server is down 1 - NNTP server is running');
-insert into help_items values (3,'pop&lt;,port&gt;','Checks if POP server is running and accepting connections0 - POP server is down 1 - POP server is running');
-insert into help_items values (3,'smtp&lt;,port&gt;','Checks if SMTP server is running and accepting connections0 - SMTP server is down 1 - SMTP server is running');
-insert into help_items values (3,'ssh&lt;,port&gt;','Checks if SSH server is running and accepting connections0 - SSH server is down 1 - SSH server is running');
-insert into help_items values (3,'tcp,port','Checks if TCP service is running and accepting connections on port0 - the serivce on the port is down 1 - the service is running');
-insert into help_items values (3,'tcp_perf,port','Checks if TCP service is running and accepting connections on port0 - the service on the port is down Otherwise, number of milliseconds spent connecting to TCP service');
-insert into help_items values (3,'ftp_perf&lt;,port&gt;','Checks if FTP server is running and accepting connections0 - FTP server is down Otherwise, number of milliseconds spent connecting to FTP server');
-insert into help_items values (3,'http_perf&lt;,port&gt;','Checks if HTTP (WEB) server is running and accepting connections0 - HTTP server is down Otherwise, number of milliseconds spent connecting to HTTP server');
-insert into help_items values (3,'imap_perf&lt;,port&gt;','Checks if IMAP server is running and accepting connections0 - IMAP server is down Otherwise, number of milliseconds spent connecting to IMAP server');
-insert into help_items values (3,'nntp_perf&lt;,port&gt;','Checks if NNTP server is running and accepting connections0 - NNTP server is down Otherwise, number of milliseconds spent connecting to NNTP server');
-insert into help_items values (3,'pop_perf&lt;,port&gt;','Checks if POP server is running and accepting connections0 - POP server is down Otherwise, number of milliseconds spent connecting to POP server');
-insert into help_items values (3,'smtp_perf&lt;,port&gt;','Checks if SMTP server is running and accepting connections0 - SMTP server is down Otherwise, number of milliseconds spent connecting to SMTP server');
-insert into help_items values (3,'ssh_perf&lt;,port&gt;','Checks if SSH server is running and accepting connections0 - SSH server is down Otherwise, number of milliseconds spent connecting to SSH server');
+insert into help_items values (3,'icmpping[&lt;ip&gt;,&lt;count&gt;,&lt;interval&gt;,&lt;size&gt;,&lt;timeout&gt;]','Checks if server is accessible by ICMP ping. 0 - ICMP ping fails. 1 - ICMP ping successful. One of zabbix_server processes performs ICMP pings once per PingerFrequency seconds.');
+insert into help_items values (3,'icmppingloss[&lt;ip&gt;,&lt;count&gt;,&lt;interval&gt;,&lt;size&gt;,&lt;timeout&gt;]','Returns percentage of lost ICMP ping packets.');
+insert into help_items values (3,'icmppingsec[&lt;ip&gt;,&lt;count&gt;,&lt;interval&gt;,&lt;size&gt;,&lt;timeout&gt;,&lt;type&gt;]','Returns ICMP ping response time in seconds. Example: 0.02');
+insert into help_items values (3,'ftp&lt;,port&gt;','Checks if FTP server is running and accepting connections. 0 - FTP server is down. 1 - FTP server is running.');
+insert into help_items values (3,'http&lt;,port&gt;','Checks if HTTP (WEB) server is running and accepting connections. 0 - HTTP server is down. 1 - HTTP server is running.');
+insert into help_items values (3,'imap&lt;,port&gt;','Checks if IMAP server is running and accepting connections. 0 - IMAP server is down. 1 - IMAP server is running.');
+insert into help_items values (3,'ldap&lt;,port&gt;','Checks if LDAP server is running and accepting connections. 0 - LDAP server is down. 1 - LDAP server is running.');
+insert into help_items values (3,'nntp&lt;,port&gt;','Checks if NNTP server is running and accepting connections. 0 - NNTP server is down. 1 - NNTP server is running.');
+insert into help_items values (3,'ntp&lt;,port&gt;','Checks if NTP server is running and accepting connections. 0 - NTP server is down. 1 - NTP server is running.');
+insert into help_items values (3,'pop&lt;,port&gt;','Checks if POP server is running and accepting connections. 0 - POP server is down. 1 - POP server is running.');
+insert into help_items values (3,'smtp&lt;,port&gt;','Checks if SMTP server is running and accepting connections. 0 - SMTP server is down. 1 - SMTP server is running.');
+insert into help_items values (3,'ssh&lt;,port&gt;','Checks if SSH server is running and accepting connections. 0 - SSH server is down. 1 - SSH server is running.');
+insert into help_items values (3,'tcp,port','Checks if TCP service is running and accepting connections on port. 0 - the service on the port is down. 1 - the service is running.');
+insert into help_items values (3,'ftp_perf&lt;,port&gt;','Checks if FTP server is running and accepting connections. 0 - FTP server is down. Otherwise, number of seconds spent connecting to FTP server.');
+insert into help_items values (3,'http_perf&lt;,port&gt;','Checks if HTTP (WEB) server is running and accepting connections. 0 - HTTP server is down. Otherwise, number of seconds spent connecting to HTTP server.');
+insert into help_items values (3,'imap_perf&lt;,port&gt;','Checks if IMAP server is running and accepting connections. 0 - IMAP server is down. Otherwise, number of seconds spent connecting to IMAP server.');
+insert into help_items values (3,'ldap_perf&lt;,port&gt;','Checks if LDAP server is running and accepting connections. 0 - LDAP server is down. Otherwise, number of seconds spent connecting to LDAP server.');
+insert into help_items values (3,'nntp_perf&lt;,port&gt;','Checks if NNTP server is running and accepting connections. 0 - NNTP server is down. Otherwise, number of seconds spent connecting to NNTP server.');
+insert into help_items values (3,'ntp_perf&lt;,port&gt;','Checks if NTP server is running and accepting connections. 0 - NTP server is down. Otherwise, number of seconds spent connecting to NTP server.');
+insert into help_items values (3,'pop_perf&lt;,port&gt;','Checks if POP server is running and accepting connections. 0 - POP server is down. Otherwise, number of milliseconds spent connecting to POP server.');
+insert into help_items values (3,'smtp_perf&lt;,port&gt;','Checks if SMTP server is running and accepting connections. 0 - SMTP server is down. Otherwise, number of seconds spent connecting to SMTP server.');
+insert into help_items values (3,'ssh_perf&lt;,port&gt;','Checks if SSH server is running and accepting connections. 0 - SSH server is down. Otherwise, number of seconds spent connecting to SSH server.');
+insert into help_items values (3,'tcp_perf,port','Checks if TCP service is running and accepting connections on port. 0 - the service on the port is down. Otherwise, number of seconds spent connecting to TCP service.');
 
-insert into help_items values (5,'zabbix[history]','Number of values stored in table HISTORY');
-insert into help_items values (5,'zabbix[history_str]','Number of values stored in table HISTORY_STR');
-insert into help_items values (5,'zabbix[items]','Number of items in Zabbix database');
-insert into help_items values (5,'zabbix[items_unsupported]','Number of unsupported items in Zabbix database');
+insert into help_items values (5,'zabbix[boottime]','Startup time of Zabbix server, Unix timestamp.');
+insert into help_items values (5,'zabbix[history]','Number of values stored in table HISTORY.');
+insert into help_items values (5,'zabbix[history_log]','Number of values stored in table HISTORY_LOG.');
+insert into help_items values (5,'zabbix[history_str]','Number of values stored in table HISTORY_STR.');
+insert into help_items values (5,'zabbix[history_text]','Number of values stored in table HISTORY_TEXT.');
+insert into help_items values (5,'zabbix[history_uint]','Number of values stored in table HISTORY_UINT.');
+insert into help_items values (5,'zabbix[items]','Number of items in Zabbix database.');
+insert into help_items values (5,'zabbix[items_unsupported]','Number of unsupported items in Zabbix database.');
 insert into help_items values (5,'zabbix[log]','Stores warning and error messages generated by Zabbix server.');
-insert into help_items values (5,'zabbix[queue]','Number of items in the queue');
-insert into help_items values (5,'zabbix[trends]','Number of values stored in table TRENDS');
-insert into help_items values (5,'zabbix[triggers]','Number of triggers in Zabbix database');
+insert into help_items values (5,'zabbix[proxy,&lt;name&gt;,&lt;param&gt;]','Time of proxy last access. Name - proxy name. Param - lastaccess. Unix timestamp.');
+insert into help_items values (5,'zabbix[queue&lt;,from&gt;&lt;,to&gt;]','Number of items in the queue which are delayed by from to to seconds, inclusive.');
+insert into help_items values (5,'zabbix[rcache,&lt;cache&gt;,&lt;mode&gt;]','Configuration cache statistics. Cache - buffer (modes: pfree, total, used, free).');
+insert into help_items values (5,'zabbix[trends]','Number of values stored in table TRENDS.');
+insert into help_items values (5,'zabbix[trends_uint]','Number of values stored in table TRENDS_UINT.');
+insert into help_items values (5,'zabbix[triggers]','Number of triggers in Zabbix database.');
+insert into help_items values (5,'zabbix[uptime]','Uptime of Zabbix server process in seconds.');
+insert into help_items values (5,'zabbix[wcache,&lt;cache&gt;,&lt;mode&gt;]','Data cache statistics. Cache - one of values (modes: all, float, uint, str, log, text), history (modes: pfree, total, used, free), trend (modes: pfree, total, used, free), text (modes: pfree, total, used, free).');
+insert into help_items values (5,'zabbix[process,&lt;type&gt;,&lt;num&gt;,&lt;state&gt;]','Time a particular Zabbix process or a group of processes (identified by &lt;type&gt; and &lt;num&gt;) spent in &lt;state&gt; in percentage.');
 
 insert into help_items values (8,'grpfunc[&lt;Group&gt;,&lt;Key&gt;,&lt;func&gt;,&lt;param&gt;]','Aggregate checks do not require any agent running on a host being monitored. Zabbix server collects aggregate information by doing direct database queries. See Zabbix Manual.');
 
@@ -165,6 +179,8 @@ insert into help_items values(0,'kernel.maxproc','Maximum number of processes su
 insert into help_items values(0,'net.if.collisions[if]','Out-of-window collision. Collisions count.');
 insert into help_items values(0,'net.if.in[if &lt;,mode&gt;]','Network interface input statistic. Integer value. If mode is missing bytes is used.');
 insert into help_items values(0,'net.if.out[if &lt;,mode&gt;]','Network interface output statistic. Integer value. If mode is missing bytes is used.');
+insert into help_items values(0,'net.if.total[if &lt;,mode&gt;]','Sum of network interface incoming and outgoing statistics. Integer value. Mode - one of bytes (default), packets, errors or dropped');
+insert into help_items values(0,'net.if.list','List of network interfaces. Text value.');
 insert into help_items values(0,'net.tcp.dns[ip, zone]','Checks if DNS service is up. 0 - DNS is down, 1 - DNS is up.');
 insert into help_items values(0,'net.tcp.dns.query[ip, zone, type]','Performs a query for the record type specified by the parameter type');
 insert into help_items values(0,'net.tcp.listen[port]','Checks if this port is in LISTEN state. 0 - it is not, 1 - it is in LISTEN state.');
@@ -179,7 +195,7 @@ insert into help_items values(0,'system.cpu.switches','Context switches.');
 insert into help_items values(0,'system.cpu.util[&lt;cpu&gt; &lt;,type&gt; &lt;,mode&gt;]','CPU(s) utilisation. Processor load in percents. The cpu, type and mode are optional. If cpu is missing all is used.  If type is missing user is used. If mode is missing avg1 is used.');
 insert into help_items values(0,'system.boottime','Timestamp of system boot.');
 insert into help_items values(0,'system.cpu.num','Number of available proccessors.');
-insert into help_items values(0,'system.hostname','Return host name. String value. Example of returned value: www.zabbix.com');
+insert into help_items values(0,'system.hostname[&lt;type&gt;]','Returns hostname (or NetBIOS name (by default) on Windows). String value. Example of returned value: www.zabbix.com');
 insert into help_items values(0,'system.localtime','System local time. Time in seconds.');
 insert into help_items values(0,'system.run[command,&lt;mode&gt]','Run specified command on the host.');
 insert into help_items values(0,'system.swap.in[&lt;swap&gt; &lt;,type&gt;]','Swap in. If type is count - swapins is returned. If type is pages - pages swapped in is returned. If swap is missing all is used.');
@@ -191,21 +207,22 @@ insert into help_items values(0,'system.users.num','Number of users connected. C
 insert into help_items values(0,'vfs.dev.read[device &lt;,type&gt; &lt;,mode&gt;]','Device read statistics.');
 insert into help_items values(0,'vfs.dev.write[device &lt;,type&gt; &lt;,mode&gt;]','Device write statistics.');
 insert into help_items values(0,'vfs.file.cksum[file]','Calculate check sum of a given file. Check sum of the file calculate by standard algorithm used by UNIX utility cksum. Example: vfs.file.cksum[/etc/passwd]');
-insert into help_items values(0,'vfs.file.exists[file]','Check file existance. 0 - file does not exists, 1 - file exists');
+insert into help_items values(0,'vfs.file.exists[file]','Check file existance. 0 - file does not exist, 1 - file exists');
 insert into help_items values(0,'vfs.file.md5sum[file]','Calculate MD5 check sum of a given file. String MD5 hash of the file. Can be used for files less than 64MB, unsupported otherwise. Example: vfs.file.md5sum[/etc/zabbix/zabbix_agentd.conf]');
 insert into help_items values(0,'vfs.file.regexp[file,regexp]','Find string in a file. Matched string');
 insert into help_items values(0,'vfs.file.regmatch[file,regexp]','Find string in a file. 0 - expression not found, 1 - found');
 insert into help_items values(0,'vfs.file.size[file]','Size of a given file. Size in bytes. File must have read permissions for user zabbix. Example: vfs.file.size[/var/log/syslog]');
-insert into help_items values(0,'vfs.file.time[file&lt;, mode&gt;]','File time information. Number of seconds.	The mode is optional. If mode is missing modify is used.');
+insert into help_items values(0,'vfs.file.time[file &lt;,mode&gt;]','File time information. Number of seconds.	The mode is optional. If mode is missing modify is used.');
 insert into help_items values(0,'vfs.fs.inode[fs &lt;,mode&gt;]','Number of inodes for a given volume. If mode is missing total is used.');
 insert into help_items values(0,'vfs.fs.size[fs &lt;,mode&gt;]','Calculate disk space for a given volume. Disk space in KB. If mode is missing total is used.  In case of mounted volume, unused disk space for local file system is returned. Example: vfs.fs.size[/tmp,free].');
 insert into help_items values(0,'vm.memory.size[&lt;mode&gt;]','Amount of memory size in bytes. If mode is missing total is used.');
 insert into help_items values(0,'web.page.get[host,&lt;path&gt;,&lt;port&gt;]','Get content of WEB page. Default path is /');
 insert into help_items values(0,'web.page.perf[host,&lt;path&gt;,&lt;port&gt;]','Get timing of loading full WEB page. Default path is /');
 insert into help_items values(0,'web.page.regexp[host,&lt;path&gt;,&lt;port&gt;,&lt;regexp&gt;,&lt;length&gt;]','Get first occurence of regexp in WEB page. Default path is /');
-insert into help_items values(0,'perf_counter[counter]','Value of any performance counter, where parameter is the counter path.');
+insert into help_items values(0,'perf_counter[counter, interval]','Value of any performance counter, where "counter" parameter is the counter path and "interval" parameter is a number of last seconds, for which the agent returns an average value.');
 insert into help_items values(0,'service_state[service]','State of service. 0 - running, 1 - paused, 2 - start pending, 3 - pause pending, 4 - continue pending, 5 - stop pending, 6 - stopped, 7 - unknown, 255 - no such service');
 insert into help_items values(0,'proc_info[&lt;process&gt;,&lt;attribute&gt;,&lt;type&gt;]','Different information about specific process(es)');
+insert into help_items values(0,'system.stat[resource &lt;,type&gt;]','Virtual memory statistics.');
 
 insert into help_items values(7,'agent.ping','Check the agent usability. Always return 1. Can be used as a TCP ping.');
 insert into help_items values(7,'agent.version','Version of zabbix_agent(d) running on monitored host. String value. Example of returned value: 1.1');
@@ -214,6 +231,8 @@ insert into help_items values(7,'kernel.maxproc','Maximum number of processes su
 insert into help_items values(7,'net.if.collisions[if]','Out-of-window collision. Collisions count.');
 insert into help_items values(7,'net.if.in[if &lt;,mode&gt;]','Network interface input statistic. Integer value. If mode is missing bytes is used.');
 insert into help_items values(7,'net.if.out[if &lt;,mode&gt;]','Network interface output statistic. Integer value. If mode is missing bytes is used.');
+insert into help_items values(7,'net.if.total[if &lt;,mode&gt;]','Sum of network interface incoming and outgoing statistics. Integer value. Mode - one of bytes (default), packets, errors or dropped');
+insert into help_items values(7,'net.if.list','List of network interfaces. Text value.');
 insert into help_items values(7,'net.tcp.dns[ip, zone]','Checks if DNS service is up. 0 - DNS is down, 1 - DNS is up.');
 insert into help_items values(7,'net.tcp.dns.query[ip, zone, type]','Performs a query for the record type specified by the parameter type');
 insert into help_items values(7,'net.tcp.listen[port]','Checks if this port is in LISTEN state. 0 - it is not, 1 - it is in LISTEN state.');
@@ -228,7 +247,7 @@ insert into help_items values(7,'system.cpu.switches','Context switches.');
 insert into help_items values(7,'system.cpu.util[&lt;cpu&gt; &lt;,type&gt; &lt;,mode&gt;]','CPU(s) utilisation. Processor load in percents. The cpu, type and mode are optional. If cpu is missing all is used.  If type is missing user is used. If mode is missing avg1 is used.');
 insert into help_items values(7,'system.boottime','Timestamp of system boot.');
 insert into help_items values(7,'system.cpu.num','Number of available proccessors.');
-insert into help_items values(7,'system.hostname','Return host name. String value. Example of returned value: www.zabbix.com');
+insert into help_items values(7,'system.hostname[&lt;type&gt;]','Returns hostname (or NetBIOS name (by default) on Windows). String value. Example of returned value: www.zabbix.com');
 insert into help_items values(7,'system.localtime','System local time. Time in seconds.');
 insert into help_items values(7,'system.run[command,&lt;mode&gt]','Run specified command on the host.');
 insert into help_items values(7,'system.swap.in[&lt;swap&gt; &lt;,type&gt;]','Swap in. If type is count - swapins is returned. If type is pages - pages swapped in is returned. If swap is missing all is used.');
@@ -240,7 +259,7 @@ insert into help_items values(7,'system.users.num','Number of users connected. C
 insert into help_items values(7,'vfs.dev.read[device &lt;,type&gt; &lt;,mode&gt;]','Device read statistics.');
 insert into help_items values(7,'vfs.dev.write[device &lt;,type&gt; &lt;,mode&gt;]','Device write statistics.');
 insert into help_items values(7,'vfs.file.cksum[file]','Calculate check sum of a given file. Check sum of the file calculate by standard algorithm used by UNIX utility cksum. Example: vfs.file.cksum[/etc/passwd]');
-insert into help_items values(7,'vfs.file.exists[file]','Check file existance. 0 - file does not exists, 1 - file exists');
+insert into help_items values(7,'vfs.file.exists[file]','Check file existance. 0 - file does not exist, 1 - file exists');
 insert into help_items values(7,'vfs.file.md5sum[file]','Calculate MD5 check sum of a given file. String MD5 hash of the file. Can be used for files less than 64MB, unsupported otherwise. Example: vfs.file.md5sum[/etc/zabbix/zabbix_agentd.conf]');
 insert into help_items values(7,'vfs.file.regexp[file,regexp]','Find string in a file. Matched string');
 insert into help_items values(7,'vfs.file.regmatch[file,regexp]','Find string in a file. 0 - expression not found, 1 - found');
@@ -258,6 +277,7 @@ insert into help_items values(7,'proc_info[&lt;process&gt;,&lt;attribute&gt;,&lt
 insert into help_items values(7,'log[file,&lt;pattern&gt;,&lt;encoding&gt;,&lt;maxlines&gt;]','Monitoring of log file. pattern - regular expression');
 insert into help_items values(7,'logrt[file_format,&lt;pattern&gt;,&lt;encoding&gt;,&lt;maxlines&gt;]', 'Monitoring of log file with rotation. fileformat - [path][regexp], pattern - regular expression');
 insert into help_items values(7,'eventlog[logtype,&lt;pattern&gt;,&lt;severity&gt;,&lt;source&gt;,&lt;eventid&gt;,&lt;maxlines&gt;]','Monitoring of Windows event logs. pattern, severity, eventid - regular expressions');
+insert into help_items values(7,'system.stat[resource &lt;,type&gt;]','Virtual memory statistics.');
 alter table history_log add logeventid              integer         DEFAULT '0'     NOT NULL;
 
 CREATE UNIQUE INDEX history_log_2 on history_log (itemid,id);
@@ -295,6 +315,7 @@ ALTER TABLE hosts ALTER COLUMN inbytes SET NOT NULL;
 ALTER TABLE hosts ALTER COLUMN outbytes TYPE numeric(20);
 ALTER TABLE hosts ALTER COLUMN outbytes SET DEFAULT '0';
 ALTER TABLE hosts ALTER COLUMN outbytes SET NOT NULL;
+CREATE INDEX hosts_templates_2 on hosts_templates (templateid);
 alter table httptest add authentication          integer         DEFAULT '0'     NOT NULL;
 alter table httptest add http_user               varchar(64)             DEFAULT ''      NOT NULL;
 alter table httptest add http_password           varchar(64)             DEFAULT ''      NOT NULL;
@@ -309,7 +330,8 @@ alter table items add password                varchar(64)             DEFAULT ''
 alter table items add publickey               varchar(64)             DEFAULT ''      NOT NULL;
 alter table items add privatekey              varchar(64)             DEFAULT ''      NOT NULL;
 alter table items add mtime                   integer         DEFAULT '0'     NOT NULL;
-CREATE TABLE maintenances_groups (
+
+UPDATE items SET units='Bps' WHERE type=9 AND units='bps';CREATE TABLE maintenances_groups (
         maintenance_groupid             bigint          DEFAULT '0'     NOT NULL,
         maintenanceid           bigint          DEFAULT '0'     NOT NULL,
         groupid         bigint          DEFAULT '0'     NOT NULL,
@@ -340,7 +362,16 @@ CREATE TABLE maintenances_windows (
         PRIMARY KEY (maintenance_timeperiodid)
 ) with OIDS;
 CREATE INDEX maintenances_windows_1 on maintenances_windows (maintenanceid,timeperiodid);
-DELETE FROM node_cksum;
+DROP TABLE node_cksum;
+CREATE TABLE node_cksum (
+	nodeid		integer		DEFAULT '0'	NOT NULL,
+	tablename		varchar(64)		DEFAULT ''	NOT NULL,
+	recordid		bigint		DEFAULT '0'	NOT NULL,
+	cksumtype		integer		DEFAULT '0'	NOT NULL,
+	cksum		text		DEFAULT ''	NOT NULL,
+	sync		char(128)		DEFAULT ''	NOT NULL
+) with OIDS;
+CREATE INDEX node_cksum_1 on node_cksum (nodeid,cksumtype,tablename,recordid);
 CREATE TABLE opmediatypes (
         opmediatypeid           bigint          DEFAULT '0'     NOT NULL,
         operationid             bigint          DEFAULT '0'     NOT NULL,
@@ -421,25 +452,23 @@ CREATE TABLE sysmaps_links_tmp (
 insert into sysmaps_links_tmp select linkid,sysmapid,selementid1,selementid2,drawtype,color,'' from sysmaps_links;
 drop table sysmaps_links;
 alter table sysmaps_links_tmp rename to sysmaps_links;
-CREATE TABLE sysmaps_tmp
-(
-  sysmapid bigint NOT NULL DEFAULT 0,
-  name varchar(128) NOT NULL DEFAULT '',
-  width integer NOT NULL DEFAULT 0,
-  height integer NOT NULL DEFAULT 0,
-  backgroundid bigint NOT NULL DEFAULT 0,
-  label_type integer NOT NULL DEFAULT 0,
-  label_location integer NOT NULL DEFAULT 0,
-  highlight integer NOT NULL DEFAULT 1
-)
-WITH (
-  OIDS=TRUE
-);
+CREATE TABLE sysmaps_tmp (
+	sysmapid		bigint		DEFAULT '0'	NOT NULL,
+	name		varchar(128)		DEFAULT ''	NOT NULL,
+	width		integer		DEFAULT '0'	NOT NULL,
+	height		integer		DEFAULT '0'	NOT NULL,
+	backgroundid		bigint		DEFAULT '0'	NOT NULL,
+	label_type		integer		DEFAULT '0'	NOT NULL,
+	label_location		integer		DEFAULT '0'	NOT NULL,
+	highlight		integer		DEFAULT '1'	NOT NULL,
+	PRIMARY KEY (sysmapid)
+) with OIDS;
 
-
-insert into sysmaps_tmp select sysmapid,name,width,height,backgroundid,label_type,label_location from sysmaps;
+insert into sysmaps_tmp select sysmapid,name,width,height,backgroundid,label_type,label_location,1 from sysmaps;
 drop table sysmaps;
 alter table sysmaps_tmp rename to sysmaps;
+
+CREATE INDEX sysmaps_1 on sysmaps (name);
 CREATE TABLE timeperiods (
         timeperiodid            bigint          DEFAULT '0'     NOT NULL,
         timeperiod_type         integer         DEFAULT '0'     NOT NULL,
